# Generated by Django 2.2.8 on 2022-05-24 15:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('departments', '0009_auto_20220524_1512'),
    ]

    operations = [
        # migrations.AlterModelTable(
        #     name='roles',
        #     table='middle_roles',
        # ),
        # migrations.AlterModelTable(
        #     name='userroles',
        #     table='middle_user_roles',
        # ),
    ]
