# Generated by Django 2.2.8 on 2022-05-20 14:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('departments', '0006_auto_20220512_1159'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='department',
            unique_together=set(),
        ),
    ]
