# Generated by Django 2.2.8 on 2022-05-12 11:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('departments', '0004_auto_20220512_1136'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='department',
            options={'ordering': ['show_order']},
        ),
        migrations.RemoveField(
            model_name='department',
            name='sort_num',
        ),
        migrations.AddField(
            model_name='department',
            name='show_order',
            field=models.IntegerField(default=0, verbose_name='顺序'),
        ),
    ]
