# Generated by Django 2.2.8 on 2022-05-24 15:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('departments', '0008_role_userrole'),
    ]

    operations = [
        # migrations.RenameModel(
        #     old_name='Role',
        #     new_name='Roles',
        # ),
        # migrations.RenameModel(
        #     old_name='UserRole',
        #     new_name='UserRoles',
        # ),
    ]
